Links class
Manages deep links and URL scheme handling
Provides path-based routing for deep links and app URL schemes
Constructors
- Links()
-
Factory constructor that returns the singleton instance
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
String prefix, LinkListener listener) → void - Register a listener for a specific URL path prefix
-
getRegisteredPrefixes(
) → List< String> - Get all registered prefixes
-
handleUri(
Uri uri) → bool - Manually handle a URI
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processLink(
Uri link) → bool - Process an incoming link by notifying appropriate listeners
-
removeListener(
String prefix, LinkListener listener) → void - Remove a previously registered listener
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited